@@ -31,8 +31,9 @@ enum {
 	COL_USER_SHELL,
 	COL_USER_COMMENT,
 	COL_USER_GROUP,
+	COL_USER_POINTER,
 
-	COL_USER_LAST,
+	COL_USER_LAST
 };
 
 typedef struct 
